@@ -14,7 +14,7 @@
 
    Copyright (C) 1999 Chris Black.
    Copyright (C) 2000 Philippe Kehl.
-   Copyright (C) 2001, 2002, 2003, 2004, 2005 Arthur de Jong.
+   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Arthur de Jong.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -123,7 +123,7 @@ static void display_version(FILE *fp)
 {
   fprintf(fp,"%s\n",PACKAGE_STRING);
   fprintf(fp,"Written by Chris Black, Philippe Kehl and Arthur de Jong.\n\n");
-  fprintf(fp,"Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005 Chris Black,\n"
+  fprintf(fp,"Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Chris Black,\n"
              "Philippe Kehl and Arthur de Jong.\n"
              "This is free software; see the source for copying conditions.  There is NO\n"
              "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n");
@@ -131,7 +131,7 @@ static void display_version(FILE *fp)
 
 
 /* display usage information to stdout and exit(status) */
-static void display_usage(FILE *fp, char *program_name)
+static void display_usage(FILE *fp, const char *program_name)
 {
   fprintf(fp,"Usage: %s [OPTION]...\n",program_name);
   fprintf(fp,"chroot wrapper to run `cvs pserver' more securely.\n");
@@ -310,7 +310,7 @@ static void exithandler(void)
 
 
 /* handle a connection by doing fork() and stuff */
-static void handleconnection(int csock,struct cvsd_cfg *cfg)
+static void handleconnection(int csock,const struct cvsd_cfg *cfg)
 {
   pid_t cpid;
   int i,m;
@@ -509,7 +509,7 @@ static void listenonaddresses(const struct cvsd_addrs *addrs)
 
 
 /* accept a connection on the socket and spawn a child cvs */
-static void acceptconnection(struct cvsd_cfg *cfg)
+static void acceptconnection(const struct cvsd_cfg *cfg)
 {
   int csock;
   fd_set fds;
